@@ -23,28 +23,36 @@
 
 import os
 
-VERSION = (0, 10, 7)
+VERSION = (0, 15, 1)
 
 __version__ = ".".join(str(v) for v in VERSION)
 __version_full__ = __version__
 
+
+def get_version():
+    return __version__
+
+
 def current_dir():
     return os.path.abspath(os.path.dirname(__file__))
 
+
 def get_html_theme_path():
     """Return list of HTML theme paths."""
     return [current_dir()]
 
+
 def get_html_static_path():
     """Return list of HTML static paths."""
     current_dir = current_dir()
     return [
-        os.path.join(current_dir, 'crate', 'static'),
+        os.path.join(current_dir, "crate", "static"),
     ]
 
+
 def get_html_template_path():
     """Return list of HTML template paths."""
     current_dir = current_dir()
     return [
-        os.path.join(current_dir, 'crate'),
+        os.path.join(current_dir, "crate"),
     ]
